Class: Google::Apis::MetastoreV1beta::BigLakeMetastoreMigrationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb

Overview

Defines the configuration required to migrate metadata from a Dataproc Metastore service to BigLake Metastore.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BigLakeMetastoreMigrationConfig

Returns a new instance of BigLakeMetastoreMigrationConfig.



407
408
409
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 407

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backfill_statusGoogle::Apis::MetastoreV1beta::BackfillStatus

Backfill status for the migration execution. Corresponds to the JSON property backfillStatus



369
370
371
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 369

def backfill_status
  @backfill_status
end

#conflict_policyString

Optional. The policy to handle conflicts when migrating resources, defaults to SKIP if not specified. Corresponds to the JSON property conflictPolicy

Returns:

  • (String)


375
376
377
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 375

def conflict_policy
  @conflict_policy
end

#dry_runBoolean Also known as: dry_run?

Optional. If true, performs discovery of requested resources and analysis against the target catalog to come up with a plan for each resource (e.g. Create, Update, Skip, etc.). No metadata is actually migrated. Corresponds to the JSON property dryRun

Returns:

  • (Boolean)


382
383
384
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 382

def dry_run
  @dry_run
end

#hive_configGoogle::Apis::MetastoreV1beta::HiveConfig

Configuration for migrating Hive metadata. Corresponds to the JSON property hiveConfig



388
389
390
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 388

def hive_config
  @hive_config
end

#iceberg_configGoogle::Apis::MetastoreV1beta::IcebergConfig

Configuration for migrating Iceberg metadata. Corresponds to the JSON property icebergConfig



393
394
395
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 393

def iceberg_config
  @iceberg_config
end

#modeString

Required. Defines the behavior of the migration execution. Corresponds to the JSON property mode

Returns:

  • (String)


398
399
400
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 398

def mode
  @mode
end

#report_pathString

Optional. The Cloud Storage path where the backfill / dry run report should be written. If not provided, the report will be generated in the service's artifacts bucket. Format: "gs://path/to/folder" Corresponds to the JSON property reportPath

Returns:

  • (String)


405
406
407
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 405

def report_path
  @report_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



412
413
414
415
416
417
418
419
420
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 412

def update!(**args)
  @backfill_status = args[:backfill_status] if args.key?(:backfill_status)
  @conflict_policy = args[:conflict_policy] if args.key?(:conflict_policy)
  @dry_run = args[:dry_run] if args.key?(:dry_run)
  @hive_config = args[:hive_config] if args.key?(:hive_config)
  @iceberg_config = args[:iceberg_config] if args.key?(:iceberg_config)
  @mode = args[:mode] if args.key?(:mode)
  @report_path = args[:report_path] if args.key?(:report_path)
end