Class: Google::Apis::MetastoreV1beta::CdcConfig
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1beta::CdcConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb
Overview
Configuration information to start the Change Data Capture (CDC) streams from customer database to backend database of Dataproc Metastore.
Instance Attribute Summary collapse
-
#bucket ⇒ String
Optional.
-
#password ⇒ String
Required.
-
#reverse_proxy_subnet ⇒ String
Required.
-
#root_path ⇒ String
Optional.
-
#subnet_ip_range ⇒ String
Required.
-
#username ⇒ String
Required.
-
#vpc_network ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CdcConfig
constructor
A new instance of CdcConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CdcConfig
Returns a new instance of CdcConfig.
656 657 658 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 656 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bucket ⇒ String
Optional. The bucket to write the intermediate stream event data in. The
bucket name must be without any prefix like "gs://". See the bucket naming
requirements (https://cloud.google.com/storage/docs/buckets#naming). This
field is optional. If not set, the Artifacts Cloud Storage bucket will be used.
Corresponds to the JSON property bucket
612 613 614 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 612 def bucket @bucket end |
#password ⇒ String
Required. Input only. The password for the user that Datastream service should
use for the MySQL connection. This field is not returned on request.
Corresponds to the JSON property password
618 619 620 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 618 def password @password end |
#reverse_proxy_subnet ⇒ String
Required. The URL of the subnetwork resource to create the VM instance hosting
the reverse proxy in. More context in https://cloud.google.com/datastream/docs/
private-connectivity#reverse-csql-proxy The subnetwork should reside in the
network provided in the request that Datastream will peer to and should be in
the same region as Datastream, in the following format. projects/project_id/
regions/region_id/subnetworks/subnetwork_id
Corresponds to the JSON property reverseProxySubnet
628 629 630 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 628 def reverse_proxy_subnet @reverse_proxy_subnet end |
#root_path ⇒ String
Optional. The root path inside the Cloud Storage bucket. The stream event data
will be written to this path. The default value is /migration.
Corresponds to the JSON property rootPath
634 635 636 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 634 def root_path @root_path end |
#subnet_ip_range ⇒ String
Required. A /29 CIDR IP range for peering with datastream.
Corresponds to the JSON property subnetIpRange
639 640 641 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 639 def subnet_ip_range @subnet_ip_range end |
#username ⇒ String
Required. The username that the Datastream service should use for the MySQL
connection.
Corresponds to the JSON property username
645 646 647 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 645 def username @username end |
#vpc_network ⇒ String
Required. Fully qualified name of the Cloud SQL instance's VPC network or the
shared VPC network that Datastream will peer to, in the following format:
projects/project_id/locations/global/networks/network_id. More context in
https://cloud.google.com/datastream/docs/network-connectivity-options#
privateconnectivity
Corresponds to the JSON property vpcNetwork
654 655 656 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 654 def vpc_network @vpc_network end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
661 662 663 664 665 666 667 668 669 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 661 def update!(**args) @bucket = args[:bucket] if args.key?(:bucket) @password = args[:password] if args.key?(:password) @reverse_proxy_subnet = args[:reverse_proxy_subnet] if args.key?(:reverse_proxy_subnet) @root_path = args[:root_path] if args.key?(:root_path) @subnet_ip_range = args[:subnet_ip_range] if args.key?(:subnet_ip_range) @username = args[:username] if args.key?(:username) @vpc_network = args[:vpc_network] if args.key?(:vpc_network) end |