Class: Google::Apis::MetastoreV1beta::CloudSqlConnectionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb

Overview

Configuration information to establish customer database connection before the cutover phase of migration

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudSqlConnectionConfig

Returns a new instance of CloudSqlConnectionConfig.



729
730
731
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 729

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hive_database_nameString

Required. The hive database name. Corresponds to the JSON property hiveDatabaseName

Returns:

  • (String)


680
681
682
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 680

def hive_database_name
  @hive_database_name
end

#instance_connection_nameString

Required. Cloud SQL database connection name (project_id:region:instance_name) Corresponds to the JSON property instanceConnectionName

Returns:

  • (String)


685
686
687
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 685

def instance_connection_name
  @instance_connection_name
end

#ip_addressString

Required. The private IP address of the Cloud SQL instance. Corresponds to the JSON property ipAddress

Returns:

  • (String)


690
691
692
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 690

def ip_address
  @ip_address
end

#nat_subnetString

Required. The relative resource name of the subnetwork to be used for Private Service Connect. Note that this cannot be a regular subnet and is used only for NAT. (https://cloud.google.com/vpc/docs/about-vpc-hosted-services#psc- subnets) This subnet is used to publish the SOCKS5 proxy service. The subnet size must be at least /29 and it should reside in a network through which the Cloud SQL instance is accessible. The resource name should be in the format, projects/project_id/regions/region_id/subnetworks/subnetwork_id Corresponds to the JSON property natSubnet

Returns:

  • (String)


701
702
703
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 701

def nat_subnet
  @nat_subnet
end

#passwordString

Required. Input only. The password for the user that Dataproc Metastore service will be using to connect to the database. This field is not returned on request. Corresponds to the JSON property password

Returns:

  • (String)


708
709
710
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 708

def password
  @password
end

#portFixnum

Required. The network port of the database. Corresponds to the JSON property port

Returns:

  • (Fixnum)


713
714
715
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 713

def port
  @port
end

#proxy_subnetString

Required. The relative resource name of the subnetwork to deploy the SOCKS5 proxy service in. The subnetwork should reside in a network through which the Cloud SQL instance is accessible. The resource name should be in the format, projects/project_id/regions/region_id/subnetworks/subnetwork_id Corresponds to the JSON property proxySubnet

Returns:

  • (String)


721
722
723
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 721

def proxy_subnet
  @proxy_subnet
end

#usernameString

Required. The username that Dataproc Metastore service will use to connect to the database. Corresponds to the JSON property username

Returns:

  • (String)


727
728
729
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 727

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



734
735
736
737
738
739
740
741
742
743
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 734

def update!(**args)
  @hive_database_name = args[:hive_database_name] if args.key?(:hive_database_name)
  @instance_connection_name = args[:instance_connection_name] if args.key?(:instance_connection_name)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @nat_subnet = args[:nat_subnet] if args.key?(:nat_subnet)
  @password = args[:password] if args.key?(:password)
  @port = args[:port] if args.key?(:port)
  @proxy_subnet = args[:proxy_subnet] if args.key?(:proxy_subnet)
  @username = args[:username] if args.key?(:username)
end