Class: Google::Apis::MetastoreV1beta::Consumer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb

Overview

Contains information of the customer's network configurations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Consumer

Returns a new instance of Consumer.



835
836
837
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 835

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endpoint_locationString

Output only. The location of the endpoint URI. Format: projects/project/ locations/location. Corresponds to the JSON property endpointLocation

Returns:

  • (String)


818
819
820
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 818

def endpoint_location
  @endpoint_location
end

#endpoint_uriString

Output only. The URI of the endpoint used to access the metastore service. Corresponds to the JSON property endpointUri

Returns:

  • (String)


823
824
825
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 823

def endpoint_uri
  @endpoint_uri
end

#subnetworkString

Immutable. The subnetwork of the customer project from which an IP address is reserved and used as the Dataproc Metastore service's endpoint. It is accessible to hosts in the subnet and to all hosts in a subnet in the same region and same network. There must be at least one IP address available in the subnet's primary range. The subnet is specified in the following form: projects/project_number/regions/region_id/subnetworks/subnetwork_id Corresponds to the JSON property subnetwork

Returns:

  • (String)


833
834
835
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 833

def subnetwork
  @subnetwork
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



840
841
842
843
844
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 840

def update!(**args)
  @endpoint_location = args[:endpoint_location] if args.key?(:endpoint_location)
  @endpoint_uri = args[:endpoint_uri] if args.key?(:endpoint_uri)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
end