Class: Google::Apis::MetastoreV1beta::DatabaseSummary
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1beta::DatabaseSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb
Overview
Summary of results for a specific database in a catalog.
Instance Attribute Summary collapse
-
#database ⇒ String
Output only.
-
#plan_action ⇒ String
Output only.
-
#result_status ⇒ String
Output only.
-
#table_summary ⇒ Google::Apis::MetastoreV1beta::TableSummary
Aggregated summary of results for all tables in a database.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DatabaseSummary
constructor
A new instance of DatabaseSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DatabaseSummary
Returns a new instance of DatabaseSummary.
996 997 998 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 996 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database ⇒ String
Output only. The name of the database.
Corresponds to the JSON property database
978 979 980 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 978 def database @database end |
#plan_action ⇒ String
Output only. The migration plan action for the database.
Corresponds to the JSON property planAction
983 984 985 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 983 def plan_action @plan_action end |
#result_status ⇒ String
Output only. The migration result status for the database. This is only set if
the migration is not a dry run.
Corresponds to the JSON property resultStatus
989 990 991 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 989 def result_status @result_status end |
#table_summary ⇒ Google::Apis::MetastoreV1beta::TableSummary
Aggregated summary of results for all tables in a database.
Corresponds to the JSON property tableSummary
994 995 996 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 994 def table_summary @table_summary end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1001 1002 1003 1004 1005 1006 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1001 def update!(**args) @database = args[:database] if args.key?(:database) @plan_action = args[:plan_action] if args.key?(:plan_action) @result_status = args[:result_status] if args.key?(:result_status) @table_summary = args[:table_summary] if args.key?(:table_summary) end |