Class: Google::Apis::MetastoreV1beta::Federation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb

Overview

Represents a federation of multiple backend metastores.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Federation

Returns a new instance of Federation.



1095
1096
1097
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1095

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_metastoresHash<String,Google::Apis::MetastoreV1beta::BackendMetastore>

A map from BackendMetastore rank to BackendMetastores from which the federation service serves metadata at query time. The map key represents the order in which BackendMetastores should be evaluated to resolve database names at query time and should be greater than or equal to zero. A BackendMetastore with a lower number will be evaluated before a BackendMetastore with a higher number. Corresponds to the JSON property backendMetastores



1037
1038
1039
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1037

def backend_metastores
  @backend_metastores
end

#create_timeString

Output only. The time when the metastore federation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1042
1043
1044
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1042

def create_time
  @create_time
end

#endpoint_uriString

Output only. The federation endpoint. Corresponds to the JSON property endpointUri

Returns:

  • (String)


1047
1048
1049
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1047

def endpoint_uri
  @endpoint_uri
end

#labelsHash<String,String>

User-defined labels for the metastore federation. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1052
1053
1054
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1052

def labels
  @labels
end

#nameString

Immutable. The relative resource name of the federation, of the form: projects/ project_number/locations/location_id/federations/federation_id. Corresponds to the JSON propertyname`

Returns:

  • (String)


1058
1059
1060
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1058

def name
  @name
end

#stateString

Output only. The current state of the federation. Corresponds to the JSON property state

Returns:

  • (String)


1063
1064
1065
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1063

def state
  @state
end

#state_messageString

Output only. Additional information about the current state of the metastore federation, if available. Corresponds to the JSON property stateMessage

Returns:

  • (String)


1069
1070
1071
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1069

def state_message
  @state_message
end

#tagsHash<String,String>

Optional. Input only. Immutable. Tag keys/values directly bound to this resource. For example: "123/environment": "production", "123/costCenter": " marketing" Corresponds to the JSON property tags

Returns:

  • (Hash<String,String>)


1076
1077
1078
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1076

def tags
  @tags
end

#uidString

Output only. The globally unique resource identifier of the metastore federation. Corresponds to the JSON property uid

Returns:

  • (String)


1082
1083
1084
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1082

def uid
  @uid
end

#update_timeString

Output only. The time when the metastore federation was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1087
1088
1089
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1087

def update_time
  @update_time
end

#versionString

Immutable. The Apache Hive metastore version of the federation. All backend metastore versions must be compatible with the federation version. Corresponds to the JSON property version

Returns:

  • (String)


1093
1094
1095
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1093

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1100

def update!(**args)
  @backend_metastores = args[:backend_metastores] if args.key?(:backend_metastores)
  @create_time = args[:create_time] if args.key?(:create_time)
  @endpoint_uri = args[:endpoint_uri] if args.key?(:endpoint_uri)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @state_message = args[:state_message] if args.key?(:state_message)
  @tags = args[:tags] if args.key?(:tags)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version = args[:version] if args.key?(:version)
end