Class: Google::Apis::MetastoreV1beta::IcebergConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb

Overview

Configuration for migrating Iceberg metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IcebergConfig

Returns a new instance of IcebergConfig.



1408
1409
1410
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1408

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#catalogString

Required. The target catalog for migrated Iceberg metadata. Format: "projects/ project_id_or_number/catalogs/catalog_id" Corresponds to the JSON property catalog

Returns:

  • (String)


1399
1400
1401
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1399

def catalog
  @catalog
end

#namespacesArray<String>

Required. The list of namespaces to migrate to the Iceberg REST catalog. Use "* " to migrate all namespaces. Note: If Hive tables exist in these namespaces, they will only be migrated if hive_config is also specified. Corresponds to the JSON property namespaces

Returns:

  • (Array<String>)


1406
1407
1408
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1406

def namespaces
  @namespaces
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1413
1414
1415
1416
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1413

def update!(**args)
  @catalog = args[:catalog] if args.key?(:catalog)
  @namespaces = args[:namespaces] if args.key?(:namespaces)
end