Class: Google::Apis::MetastoreV1beta::LocationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb

Overview

Metadata about the service in a location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LocationMetadata

Returns a new instance of LocationMetadata.



1827
1828
1829
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1827

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_region_metadataArray<Google::Apis::MetastoreV1beta::CustomRegionMetadata>

Deprecated: Use a single region service instead. Possible configurations supported if the current region is a custom region. Corresponds to the JSON property customRegionMetadata



1810
1811
1812
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1810

def 
  @custom_region_metadata
end

#multi_region_metadataGoogle::Apis::MetastoreV1beta::MultiRegionMetadata

Deprecated: Use a single region service instead. The metadata for the multi- region that includes the constituent regions. The metadata is only populated if the region is multi-region. For single region or custom dual region, it will be empty. Corresponds to the JSON property multiRegionMetadata



1818
1819
1820
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1818

def 
  @multi_region_metadata
end

#supported_hive_metastore_versionsArray<Google::Apis::MetastoreV1beta::HiveMetastoreVersion>

The versions of Hive Metastore that can be used when creating a new metastore service in this location. The server guarantees that exactly one HiveMetastoreVersion in the list will set is_default. Corresponds to the JSON property supportedHiveMetastoreVersions



1825
1826
1827
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1825

def supported_hive_metastore_versions
  @supported_hive_metastore_versions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1832
1833
1834
1835
1836
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1832

def update!(**args)
  @custom_region_metadata = args[:custom_region_metadata] if args.key?(:custom_region_metadata)
  @multi_region_metadata = args[:multi_region_metadata] if args.key?(:multi_region_metadata)
  @supported_hive_metastore_versions = args[:supported_hive_metastore_versions] if args.key?(:supported_hive_metastore_versions)
end