Class: Google::Apis::MetastoreV1beta::MetadataImport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb

Overview

A metastore resource that imports metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetadataImport

Returns a new instance of MetadataImport.



1972
1973
1974
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1972

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the metadata import was started. Corresponds to the JSON property createTime

Returns:

  • (String)


1937
1938
1939
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1937

def create_time
  @create_time
end

#database_dumpGoogle::Apis::MetastoreV1beta::DatabaseDump

A specification of the location of and metadata about a database dump from a relational database management system. Corresponds to the JSON property databaseDump



1943
1944
1945
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1943

def database_dump
  @database_dump
end

#descriptionString

Optional. The description of the metadata import. Corresponds to the JSON property description

Returns:

  • (String)


1948
1949
1950
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1948

def description
  @description
end

#end_timeString

Output only. The time when the metadata import finished. Corresponds to the JSON property endTime

Returns:

  • (String)


1953
1954
1955
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1953

def end_time
  @end_time
end

#nameString

Immutable. Identifier. The relative resource name of the metadata import, of the form:projects/project_number/locations/location_id/services/ service_id/metadataImports/metadata_import_id. Corresponds to the JSON property name

Returns:

  • (String)


1960
1961
1962
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1960

def name
  @name
end

#stateString

Output only. The current state of the metadata import. Corresponds to the JSON property state

Returns:

  • (String)


1965
1966
1967
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1965

def state
  @state
end

#update_timeString

Output only. The time when the metadata import was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1970
1971
1972
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1970

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1977
1978
1979
1980
1981
1982
1983
1984
1985
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1977

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @database_dump = args[:database_dump] if args.key?(:database_dump)
  @description = args[:description] if args.key?(:description)
  @end_time = args[:end_time] if args.key?(:end_time)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end