Class: Google::Apis::MetastoreV1beta::MetadataIntegration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb

Overview

Specifies how metastore metadata should be integrated with external services.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetadataIntegration

Returns a new instance of MetadataIntegration.



1783
1784
1785
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1783

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_catalog_configGoogle::Apis::MetastoreV1beta::DataCatalogConfig

Specifies how metastore metadata should be integrated with the Data Catalog service. Corresponds to the JSON property dataCatalogConfig



1775
1776
1777
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1775

def data_catalog_config
  @data_catalog_config
end

#dataplex_configGoogle::Apis::MetastoreV1beta::DataplexConfig

Specifies how metastore metadata should be integrated with the Dataplex service. Corresponds to the JSON property dataplexConfig



1781
1782
1783
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1781

def dataplex_config
  @dataplex_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1788
1789
1790
1791
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1788

def update!(**args)
  @data_catalog_config = args[:data_catalog_config] if args.key?(:data_catalog_config)
  @dataplex_config = args[:dataplex_config] if args.key?(:dataplex_config)
end