Class: Google::Apis::MetastoreV1beta::MigrationExecution
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1beta::MigrationExecution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb
Overview
The details of a migration execution resource.
Instance Attribute Summary collapse
-
#biglake_metastore_migration_config ⇒ Google::Apis::MetastoreV1beta::BigLakeMetastoreMigrationConfig
Defines the configuration required to migrate metadata from a Dataproc Metastore service to BigLake Metastore.
-
#cloud_sql_migration_config ⇒ Google::Apis::MetastoreV1beta::CloudSqlMigrationConfig
Deprecated: Migrations to Dataproc Metastore are no longer supported.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#phase ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#state_message ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MigrationExecution
constructor
A new instance of MigrationExecution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MigrationExecution
Returns a new instance of MigrationExecution.
2093 2094 2095 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2093 def initialize(**args) update!(**args) end |
Instance Attribute Details
#biglake_metastore_migration_config ⇒ Google::Apis::MetastoreV1beta::BigLakeMetastoreMigrationConfig
Defines the configuration required to migrate metadata from a Dataproc
Metastore service to BigLake Metastore.
Corresponds to the JSON property biglakeMetastoreMigrationConfig
2048 2049 2050 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2048 def @biglake_metastore_migration_config end |
#cloud_sql_migration_config ⇒ Google::Apis::MetastoreV1beta::CloudSqlMigrationConfig
Deprecated: Migrations to Dataproc Metastore are no longer supported. Use
BigLake Metastore migration instead. Configuration information for migrating
from self-managed hive metastore on Google Cloud using Cloud SQL as the
backend database to Dataproc Metastore.
Corresponds to the JSON property cloudSqlMigrationConfig
2056 2057 2058 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2056 def cloud_sql_migration_config @cloud_sql_migration_config end |
#create_time ⇒ String
Output only. The time when the migration execution was started.
Corresponds to the JSON property createTime
2061 2062 2063 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2061 def create_time @create_time end |
#end_time ⇒ String
Output only. The time when the migration execution finished.
Corresponds to the JSON property endTime
2066 2067 2068 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2066 def end_time @end_time end |
#name ⇒ String
Output only. The relative resource name of the migration execution, in the
following form: projects/project_number/locations/location_id/services/
service_id/migrationExecutions/migration_execution_id
Corresponds to the JSON property name
2073 2074 2075 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2073 def name @name end |
#phase ⇒ String
Output only. Deprecated: Phase was designed for incoming migrations to
Dataproc Metastore, not applicable when migrating away from it. The current
phase of the migration execution.
Corresponds to the JSON property phase
2080 2081 2082 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2080 def phase @phase end |
#state ⇒ String
Output only. The current state of the migration execution.
Corresponds to the JSON property state
2085 2086 2087 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2085 def state @state end |
#state_message ⇒ String
Output only. Additional information about the current state of the migration
execution.
Corresponds to the JSON property stateMessage
2091 2092 2093 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2091 def @state_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2098 def update!(**args) @biglake_metastore_migration_config = args[:biglake_metastore_migration_config] if args.key?(:biglake_metastore_migration_config) @cloud_sql_migration_config = args[:cloud_sql_migration_config] if args.key?(:cloud_sql_migration_config) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @name = args[:name] if args.key?(:name) @phase = args[:phase] if args.key?(:phase) @state = args[:state] if args.key?(:state) @state_message = args[:state_message] if args.key?(:state_message) end |