Class: Google::Apis::MetastoreV1beta::MultiRegionMetadata
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1beta::MultiRegionMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb
Overview
Deprecated: Use a single region service instead. The metadata for the multi- region that includes the constituent regions. The metadata is only populated if the region is multi-region. For single region or custom dual region, it will be empty.
Instance Attribute Summary collapse
-
#constituent_regions ⇒ Array<String>
The regions constituting the multi-region.
-
#continent ⇒ String
The continent for this multi-region.
-
#witness_region ⇒ String
The Spanner witness region for this multi-region.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MultiRegionMetadata
constructor
A new instance of MultiRegionMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MultiRegionMetadata
Returns a new instance of MultiRegionMetadata.
1974 1975 1976 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1974 def initialize(**args) update!(**args) end |
Instance Attribute Details
#constituent_regions ⇒ Array<String>
The regions constituting the multi-region.
Corresponds to the JSON property constituentRegions
1962 1963 1964 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1962 def constituent_regions @constituent_regions end |
#continent ⇒ String
The continent for this multi-region.
Corresponds to the JSON property continent
1967 1968 1969 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1967 def continent @continent end |
#witness_region ⇒ String
The Spanner witness region for this multi-region.
Corresponds to the JSON property witnessRegion
1972 1973 1974 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1972 def witness_region @witness_region end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1979 1980 1981 1982 1983 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1979 def update!(**args) @constituent_regions = args[:constituent_regions] if args.key?(:constituent_regions) @continent = args[:continent] if args.key?(:continent) @witness_region = args[:witness_region] if args.key?(:witness_region) end |