Class: Google::Apis::MetastoreV1beta::Restore
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1beta::Restore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb
Overview
The details of a metadata restore operation.
Instance Attribute Summary collapse
-
#backup ⇒ String
Output only.
-
#backup_location ⇒ String
Optional.
-
#details ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Restore
constructor
A new instance of Restore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Restore
Returns a new instance of Restore.
2625 2626 2627 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2625 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup ⇒ String
Output only. The relative resource name of the metastore service backup to
restore from, in the following form:projects/project_id/locations/
location_id/services/service_id/backups/backup_id.
Corresponds to the JSON property backup
2591 2592 2593 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2591 def backup @backup end |
#backup_location ⇒ String
Optional. A Cloud Storage URI specifying where the backup artifacts are stored,
in the format gs:///.
Corresponds to the JSON property backupLocation
2597 2598 2599 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2597 def backup_location @backup_location end |
#details ⇒ String
Output only. The restore details containing the revision of the service to be
restored to, in format of JSON.
Corresponds to the JSON property details
2603 2604 2605 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2603 def details @details end |
#end_time ⇒ String
Output only. The time when the restore ended.
Corresponds to the JSON property endTime
2608 2609 2610 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2608 def end_time @end_time end |
#start_time ⇒ String
Output only. The time when the restore started.
Corresponds to the JSON property startTime
2613 2614 2615 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2613 def start_time @start_time end |
#state ⇒ String
Output only. The current state of the restore.
Corresponds to the JSON property state
2618 2619 2620 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2618 def state @state end |
#type ⇒ String
Output only. The type of restore.
Corresponds to the JSON property type
2623 2624 2625 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2623 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2630 2631 2632 2633 2634 2635 2636 2637 2638 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2630 def update!(**args) @backup = args[:backup] if args.key?(:backup) @backup_location = args[:backup_location] if args.key?(:backup_location) @details = args[:details] if args.key?(:details) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) end |