Class: Google::Apis::MetastoreV1beta::ScalingConfig
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1beta::ScalingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb
Overview
Represents the scaling configuration of a metastore service.
Instance Attribute Summary collapse
-
#autoscaling_config ⇒ Google::Apis::MetastoreV1beta::AutoscalingConfig
Represents the autoscaling configuration of a metastore service.
-
#instance_size ⇒ String
An enum of readable instance sizes, with each instance size mapping to a float value (e.g. InstanceSize.EXTRA_SMALL = scaling_factor(0.1)) Corresponds to the JSON property
instanceSize. -
#scaling_factor ⇒ Float
Scaling factor, increments of 0.1 for values less than 1.0, and increments of 1.0 for values greater than 1.0.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ScalingConfig
constructor
A new instance of ScalingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ScalingConfig
Returns a new instance of ScalingConfig.
2459 2460 2461 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2459 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoscaling_config ⇒ Google::Apis::MetastoreV1beta::AutoscalingConfig
Represents the autoscaling configuration of a metastore service.
Corresponds to the JSON property autoscalingConfig
2445 2446 2447 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2445 def autoscaling_config @autoscaling_config end |
#instance_size ⇒ String
An enum of readable instance sizes, with each instance size mapping to a float
value (e.g. InstanceSize.EXTRA_SMALL = scaling_factor(0.1))
Corresponds to the JSON property instanceSize
2451 2452 2453 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2451 def instance_size @instance_size end |
#scaling_factor ⇒ Float
Scaling factor, increments of 0.1 for values less than 1.0, and increments of
1.0 for values greater than 1.0.
Corresponds to the JSON property scalingFactor
2457 2458 2459 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2457 def scaling_factor @scaling_factor end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2464 2465 2466 2467 2468 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2464 def update!(**args) @autoscaling_config = args[:autoscaling_config] if args.key?(:autoscaling_config) @instance_size = args[:instance_size] if args.key?(:instance_size) @scaling_factor = args[:scaling_factor] if args.key?(:scaling_factor) end |