Class: Google::Apis::MetastoreV1beta::ScheduledBackup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb

Overview

This specifies the configuration of scheduled backup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScheduledBackup

Returns a new instance of ScheduledBackup.



2795
2796
2797
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_locationString

Optional. A Cloud Storage URI of a folder, in the format gs:///. A sub-folder containing backup files will be stored below it. Corresponds to the JSON property backupLocation

Returns:

  • (String)


2761
2762
2763
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2761

def backup_location
  @backup_location
end

#cron_scheduleString

Optional. The scheduled interval in Cron format, see https://en.wikipedia.org/ wiki/Cron The default is empty: scheduled backup is not enabled. Must be specified to enable scheduled backups. Corresponds to the JSON property cronSchedule

Returns:

  • (String)


2768
2769
2770
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2768

def cron_schedule
  @cron_schedule
end

#enabledBoolean Also known as: enabled?

Optional. Defines whether the scheduled backup is enabled. The default value is false. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


2774
2775
2776
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2774

def enabled
  @enabled
end

#latest_backupGoogle::Apis::MetastoreV1beta::LatestBackup

The details of the latest scheduled backup. Corresponds to the JSON property latestBackup



2780
2781
2782
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2780

def latest_backup
  @latest_backup
end

#next_scheduled_timeString

Output only. The time when the next backups execution is scheduled to start. Corresponds to the JSON property nextScheduledTime

Returns:

  • (String)


2785
2786
2787
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2785

def next_scheduled_time
  @next_scheduled_time
end

#time_zoneString

Optional. Specifies the time zone to be used when interpreting cron_schedule. Must be a time zone name from the time zone database (https://en.wikipedia.org/ wiki/List_of_tz_database_time_zones), e.g. America/Los_Angeles or Africa/ Abidjan. If left unspecified, the default is UTC. Corresponds to the JSON property timeZone

Returns:

  • (String)


2793
2794
2795
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2793

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2800
2801
2802
2803
2804
2805
2806
2807
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2800

def update!(**args)
  @backup_location = args[:backup_location] if args.key?(:backup_location)
  @cron_schedule = args[:cron_schedule] if args.key?(:cron_schedule)
  @enabled = args[:enabled] if args.key?(:enabled)
  @latest_backup = args[:latest_backup] if args.key?(:latest_backup)
  @next_scheduled_time = args[:next_scheduled_time] if args.key?(:next_scheduled_time)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end