Class: Google::Apis::MetastoreV1beta::Service

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb

Overview

A managed metastore service that serves metadata queries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Service

Returns a new instance of Service.



2980
2981
2982
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2980

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_gcs_uriString

Output only. A Cloud Storage URI (starting with gs://) that specifies where artifacts related to the metastore service are stored. Corresponds to the JSON property artifactGcsUri

Returns:

  • (String)


2839
2840
2841
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2839

def artifact_gcs_uri
  @artifact_gcs_uri
end

#create_timeString

Output only. The time when the metastore service was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2844
2845
2846
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2844

def create_time
  @create_time
end

#database_typeString

Immutable. The database type that the Metastore service stores its data. Corresponds to the JSON property databaseType

Returns:

  • (String)


2849
2850
2851
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2849

def database_type
  @database_type
end

#deletion_protectionBoolean Also known as: deletion_protection?

Optional. Indicates if the dataproc metastore should be protected against accidental deletions. Corresponds to the JSON property deletionProtection

Returns:

  • (Boolean)


2855
2856
2857
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2855

def deletion_protection
  @deletion_protection
end

#encryption_configGoogle::Apis::MetastoreV1beta::EncryptionConfig

Encryption settings for the service. Corresponds to the JSON property encryptionConfig



2861
2862
2863
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2861

def encryption_config
  @encryption_config
end

#endpoint_uriString

Output only. The URI of the endpoint used to access the metastore service. Corresponds to the JSON property endpointUri

Returns:

  • (String)


2866
2867
2868
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2866

def endpoint_uri
  @endpoint_uri
end

#hive_metastore_configGoogle::Apis::MetastoreV1beta::HiveMetastoreConfig

Specifies configuration information specific to running Hive metastore software as the metastore service. Corresponds to the JSON property hiveMetastoreConfig



2872
2873
2874
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2872

def hive_metastore_config
  @hive_metastore_config
end

#labelsHash<String,String>

User-defined labels for the metastore service. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2877
2878
2879
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2877

def labels
  @labels
end

#maintenance_windowGoogle::Apis::MetastoreV1beta::MaintenanceWindow

Maintenance window. This specifies when Dataproc Metastore may perform system maintenance operation to the service. Corresponds to the JSON property maintenanceWindow



2883
2884
2885
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2883

def maintenance_window
  @maintenance_window
end

#metadata_integrationGoogle::Apis::MetastoreV1beta::MetadataIntegration

Specifies how metastore metadata should be integrated with external services. Corresponds to the JSON property metadataIntegration



2888
2889
2890
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2888

def 
  @metadata_integration
end

#metadata_management_activityGoogle::Apis::MetastoreV1beta::MetadataManagementActivity

The metadata management activities of the metastore service. Corresponds to the JSON property metadataManagementActivity



2893
2894
2895
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2893

def 
  @metadata_management_activity
end

#multi_region_configGoogle::Apis::MetastoreV1beta::MultiRegionConfig

Deprecated: Use a single region service instead. The multi-region config for the Dataproc Metastore service. Corresponds to the JSON property multiRegionConfig



2899
2900
2901
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2899

def multi_region_config
  @multi_region_config
end

#nameString

Immutable. Identifier. The relative resource name of the metastore service, in the following format:projects/project_number/locations/location_id/ services/service_id. Corresponds to the JSON property name

Returns:

  • (String)


2906
2907
2908
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2906

def name
  @name
end

#networkString

Immutable. The relative resource name of the VPC network on which the instance can be accessed. It is specified in the following form:projects/ project_number/global/networks/network_id. Corresponds to the JSON property network

Returns:

  • (String)


2913
2914
2915
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2913

def network
  @network
end

#network_configGoogle::Apis::MetastoreV1beta::NetworkConfig

Network configuration for the Dataproc Metastore service. Corresponds to the JSON property networkConfig



2918
2919
2920
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2918

def network_config
  @network_config
end

#portFixnum

Optional. The TCP port at which the metastore service is reached. Default: 9083. Corresponds to the JSON property port

Returns:

  • (Fixnum)


2924
2925
2926
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2924

def port
  @port
end

#release_channelString

Immutable. The release channel of the service. If unspecified, defaults to STABLE. Corresponds to the JSON property releaseChannel

Returns:

  • (String)


2930
2931
2932
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2930

def release_channel
  @release_channel
end

#scaling_configGoogle::Apis::MetastoreV1beta::ScalingConfig

Represents the scaling configuration of a metastore service. Corresponds to the JSON property scalingConfig



2935
2936
2937
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2935

def scaling_config
  @scaling_config
end

#scheduled_backupGoogle::Apis::MetastoreV1beta::ScheduledBackup

This specifies the configuration of scheduled backup. Corresponds to the JSON property scheduledBackup



2940
2941
2942
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2940

def scheduled_backup
  @scheduled_backup
end

#stateString

Output only. The current state of the metastore service. Corresponds to the JSON property state

Returns:

  • (String)


2945
2946
2947
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2945

def state
  @state
end

#state_messageString

Output only. Additional information about the current state of the metastore service, if available. Corresponds to the JSON property stateMessage

Returns:

  • (String)


2951
2952
2953
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2951

def state_message
  @state_message
end

#tagsHash<String,String>

Optional. Input only. Immutable. Tag keys/values directly bound to this resource. For example: "123/environment": "production", "123/costCenter": " marketing" Corresponds to the JSON property tags

Returns:

  • (Hash<String,String>)


2958
2959
2960
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2958

def tags
  @tags
end

#telemetry_configGoogle::Apis::MetastoreV1beta::TelemetryConfig

Telemetry Configuration for the Dataproc Metastore service. Corresponds to the JSON property telemetryConfig



2963
2964
2965
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2963

def telemetry_config
  @telemetry_config
end

#tierString

Optional. The tier of the service. Corresponds to the JSON property tier

Returns:

  • (String)


2968
2969
2970
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2968

def tier
  @tier
end

#uidString

Output only. The globally unique resource identifier of the metastore service. Corresponds to the JSON property uid

Returns:

  • (String)


2973
2974
2975
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2973

def uid
  @uid
end

#update_timeString

Output only. The time when the metastore service was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2978
2979
2980
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2978

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2985
2986
2987
2988
2989
2990
2991
2992
2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2985

def update!(**args)
  @artifact_gcs_uri = args[:artifact_gcs_uri] if args.key?(:artifact_gcs_uri)
  @create_time = args[:create_time] if args.key?(:create_time)
  @database_type = args[:database_type] if args.key?(:database_type)
  @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection)
  @encryption_config = args[:encryption_config] if args.key?(:encryption_config)
  @endpoint_uri = args[:endpoint_uri] if args.key?(:endpoint_uri)
  @hive_metastore_config = args[:hive_metastore_config] if args.key?(:hive_metastore_config)
  @labels = args[:labels] if args.key?(:labels)
  @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window)
  @metadata_integration = args[:metadata_integration] if args.key?(:metadata_integration)
  @metadata_management_activity = args[:metadata_management_activity] if args.key?(:metadata_management_activity)
  @multi_region_config = args[:multi_region_config] if args.key?(:multi_region_config)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @network_config = args[:network_config] if args.key?(:network_config)
  @port = args[:port] if args.key?(:port)
  @release_channel = args[:release_channel] if args.key?(:release_channel)
  @scaling_config = args[:scaling_config] if args.key?(:scaling_config)
  @scheduled_backup = args[:scheduled_backup] if args.key?(:scheduled_backup)
  @state = args[:state] if args.key?(:state)
  @state_message = args[:state_message] if args.key?(:state_message)
  @tags = args[:tags] if args.key?(:tags)
  @telemetry_config = args[:telemetry_config] if args.key?(:telemetry_config)
  @tier = args[:tier] if args.key?(:tier)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end