Class: Google::Apis::MetastoreV1beta::TestIamPermissionsRequest
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1beta::TestIamPermissionsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb
Overview
Request message for TestIamPermissions method.
Instance Attribute Summary collapse
-
#permissions ⇒ Array<String>
The set of permissions to check for the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TestIamPermissionsRequest
constructor
A new instance of TestIamPermissionsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TestIamPermissionsRequest
Returns a new instance of TestIamPermissionsRequest.
2956 2957 2958 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2956 def initialize(**args) update!(**args) end |
Instance Attribute Details
#permissions ⇒ Array<String>
The set of permissions to check for the resource. Permissions with wildcards (
such as * or storage.*) are not allowed. For more information see IAM Overview
(https://cloud.google.com/iam/docs/overview#permissions).
Corresponds to the JSON property permissions
2954 2955 2956 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2954 def @permissions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2961 2962 2963 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2961 def update!(**args) @permissions = args[:permissions] if args.key?(:permissions) end |