Class: Google::Apis::MetastoreV1beta::Federation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb

Overview

Represents a federation of multiple backend metastores.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Federation

Returns a new instance of Federation.



1093
1094
1095
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1093

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_metastoresHash<String,Google::Apis::MetastoreV1beta::BackendMetastore>

A map from BackendMetastore rank to BackendMetastores from which the federation service serves metadata at query time. The map key represents the order in which BackendMetastores should be evaluated to resolve database names at query time and should be greater than or equal to zero. A BackendMetastore with a lower number will be evaluated before a BackendMetastore with a higher number. Corresponds to the JSON property backendMetastores



1035
1036
1037
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1035

def backend_metastores
  @backend_metastores
end

#create_timeString

Output only. The time when the metastore federation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1040
1041
1042
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1040

def create_time
  @create_time
end

#endpoint_uriString

Output only. The federation endpoint. Corresponds to the JSON property endpointUri

Returns:

  • (String)


1045
1046
1047
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1045

def endpoint_uri
  @endpoint_uri
end

#labelsHash<String,String>

User-defined labels for the metastore federation. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1050
1051
1052
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1050

def labels
  @labels
end

#nameString

Immutable. The relative resource name of the federation, of the form: projects/ project_number/locations/location_id/federations/federation_id. Corresponds to the JSON propertyname`

Returns:

  • (String)


1056
1057
1058
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1056

def name
  @name
end

#stateString

Output only. The current state of the federation. Corresponds to the JSON property state

Returns:

  • (String)


1061
1062
1063
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1061

def state
  @state
end

#state_messageString

Output only. Additional information about the current state of the metastore federation, if available. Corresponds to the JSON property stateMessage

Returns:

  • (String)


1067
1068
1069
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1067

def state_message
  @state_message
end

#tagsHash<String,String>

Optional. Input only. Immutable. Tag keys/values directly bound to this resource. For example: "123/environment": "production", "123/costCenter": " marketing" Corresponds to the JSON property tags

Returns:

  • (Hash<String,String>)


1074
1075
1076
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1074

def tags
  @tags
end

#uidString

Output only. The globally unique resource identifier of the metastore federation. Corresponds to the JSON property uid

Returns:

  • (String)


1080
1081
1082
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1080

def uid
  @uid
end

#update_timeString

Output only. The time when the metastore federation was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1085
1086
1087
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1085

def update_time
  @update_time
end

#versionString

Immutable. The Apache Hive metastore version of the federation. All backend metastore versions must be compatible with the federation version. Corresponds to the JSON property version

Returns:

  • (String)


1091
1092
1093
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1091

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1098

def update!(**args)
  @backend_metastores = args[:backend_metastores] if args.key?(:backend_metastores)
  @create_time = args[:create_time] if args.key?(:create_time)
  @endpoint_uri = args[:endpoint_uri] if args.key?(:endpoint_uri)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @state_message = args[:state_message] if args.key?(:state_message)
  @tags = args[:tags] if args.key?(:tags)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version = args[:version] if args.key?(:version)
end