Class: Google::Apis::MetastoreV1beta::HiveMetastoreConfig
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1beta::HiveMetastoreConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb
Overview
Specifies configuration information specific to running Hive metastore software as the metastore service.
Instance Attribute Summary collapse
-
#auxiliary_versions ⇒ Hash<String,Google::Apis::MetastoreV1beta::AuxiliaryVersionConfig>
Optional.
-
#config_overrides ⇒ Hash<String,String>
Optional.
-
#endpoint_protocol ⇒ String
Optional.
-
#kerberos_config ⇒ Google::Apis::MetastoreV1beta::KerberosConfig
Configuration information for a Kerberos principal.
-
#version ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HiveMetastoreConfig
constructor
A new instance of HiveMetastoreConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HiveMetastoreConfig
Returns a new instance of HiveMetastoreConfig.
1157 1158 1159 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1157 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auxiliary_versions ⇒ Hash<String,Google::Apis::MetastoreV1beta::AuxiliaryVersionConfig>
Optional. A mapping of Hive metastore version to the auxiliary version
configuration. When specified, a secondary Hive metastore service is created
along with the primary service. All auxiliary versions must be less than the
service's primary version. The key is the auxiliary service name and it must
match the regular expression a-z?. This means that the first character must be
a lowercase letter, and all the following characters must be hyphens,
lowercase letters, or digits, except the last character, which cannot be a
hyphen.
Corresponds to the JSON property auxiliaryVersions
1130 1131 1132 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1130 def auxiliary_versions @auxiliary_versions end |
#config_overrides ⇒ Hash<String,String>
Optional. A mapping of Hive metastore configuration key-value pairs to apply
to the Hive metastore (configured in hive-site.xml). The mappings override
system defaults (some keys cannot be overridden). These overrides are also
applied to auxiliary versions and can be further customized in the auxiliary
version's AuxiliaryVersionConfig.
Corresponds to the JSON property configOverrides
1139 1140 1141 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1139 def config_overrides @config_overrides end |
#endpoint_protocol ⇒ String
Optional. The protocol to use for the metastore service endpoint. If
unspecified, defaults to THRIFT.
Corresponds to the JSON property endpointProtocol
1145 1146 1147 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1145 def endpoint_protocol @endpoint_protocol end |
#kerberos_config ⇒ Google::Apis::MetastoreV1beta::KerberosConfig
Configuration information for a Kerberos principal.
Corresponds to the JSON property kerberosConfig
1150 1151 1152 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1150 def kerberos_config @kerberos_config end |
#version ⇒ String
Immutable. The Hive metastore schema version.
Corresponds to the JSON property version
1155 1156 1157 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1155 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1162 1163 1164 1165 1166 1167 1168 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1162 def update!(**args) @auxiliary_versions = args[:auxiliary_versions] if args.key?(:auxiliary_versions) @config_overrides = args[:config_overrides] if args.key?(:config_overrides) @endpoint_protocol = args[:endpoint_protocol] if args.key?(:endpoint_protocol) @kerberos_config = args[:kerberos_config] if args.key?(:kerberos_config) @version = args[:version] if args.key?(:version) end |