Class: Google::Apis::MetastoreV1beta::HiveMetastoreConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb

Overview

Specifies configuration information specific to running Hive metastore software as the metastore service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HiveMetastoreConfig

Returns a new instance of HiveMetastoreConfig.



1155
1156
1157
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1155

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auxiliary_versionsHash<String,Google::Apis::MetastoreV1beta::AuxiliaryVersionConfig>

Optional. A mapping of Hive metastore version to the auxiliary version configuration. When specified, a secondary Hive metastore service is created along with the primary service. All auxiliary versions must be less than the service's primary version. The key is the auxiliary service name and it must match the regular expression a-z?. This means that the first character must be a lowercase letter, and all the following characters must be hyphens, lowercase letters, or digits, except the last character, which cannot be a hyphen. Corresponds to the JSON property auxiliaryVersions



1128
1129
1130
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1128

def auxiliary_versions
  @auxiliary_versions
end

#config_overridesHash<String,String>

Optional. A mapping of Hive metastore configuration key-value pairs to apply to the Hive metastore (configured in hive-site.xml). The mappings override system defaults (some keys cannot be overridden). These overrides are also applied to auxiliary versions and can be further customized in the auxiliary version's AuxiliaryVersionConfig. Corresponds to the JSON property configOverrides

Returns:

  • (Hash<String,String>)


1137
1138
1139
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1137

def config_overrides
  @config_overrides
end

#endpoint_protocolString

Optional. The protocol to use for the metastore service endpoint. If unspecified, defaults to THRIFT. Corresponds to the JSON property endpointProtocol

Returns:

  • (String)


1143
1144
1145
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1143

def endpoint_protocol
  @endpoint_protocol
end

#kerberos_configGoogle::Apis::MetastoreV1beta::KerberosConfig

Configuration information for a Kerberos principal. Corresponds to the JSON property kerberosConfig



1148
1149
1150
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1148

def kerberos_config
  @kerberos_config
end

#versionString

Immutable. The Hive metastore schema version. Corresponds to the JSON property version

Returns:

  • (String)


1153
1154
1155
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1153

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1160
1161
1162
1163
1164
1165
1166
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1160

def update!(**args)
  @auxiliary_versions = args[:auxiliary_versions] if args.key?(:auxiliary_versions)
  @config_overrides = args[:config_overrides] if args.key?(:config_overrides)
  @endpoint_protocol = args[:endpoint_protocol] if args.key?(:endpoint_protocol)
  @kerberos_config = args[:kerberos_config] if args.key?(:kerberos_config)
  @version = args[:version] if args.key?(:version)
end