Class: Google::Apis::MetastoreV1beta::MessageSet
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1beta::MessageSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb
Overview
This is proto2's version of MessageSet.DEPRECATED: DO NOT USE FOR NEW FIELDS. If you are using editions or proto2, please make your own extendable messages for your use case. If you are using proto3, please use Any instead.MessageSet was the implementation of extensions for proto1. When proto2 was introduced, extensions were implemented as a first-class feature. This schema for MessageSet was meant to be a "bridge" solution to migrate MessageSet-bearing messages from proto1 to proto2.This schema has been open-sourced only to facilitate the migration of Google products with MessageSet-bearing messages to open-source environments.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MessageSet
constructor
A new instance of MessageSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MessageSet
Returns a new instance of MessageSet.
1652 1653 1654 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1652 def initialize(**args) update!(**args) end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1657 1658 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1657 def update!(**args) end |