Class: Google::Apis::MetastoreV1beta::MetadataImport
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1beta::MetadataImport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb
Overview
A metastore resource that imports metadata.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#database_dump ⇒ Google::Apis::MetastoreV1beta::DatabaseDump
A specification of the location of and metadata about a database dump from a relational database management system.
-
#description ⇒ String
Optional.
-
#end_time ⇒ String
Output only.
-
#name ⇒ String
Immutable.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetadataImport
constructor
A new instance of MetadataImport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetadataImport
Returns a new instance of MetadataImport.
1747 1748 1749 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1747 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the metadata import was started.
Corresponds to the JSON property createTime
1712 1713 1714 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1712 def create_time @create_time end |
#database_dump ⇒ Google::Apis::MetastoreV1beta::DatabaseDump
A specification of the location of and metadata about a database dump from a
relational database management system.
Corresponds to the JSON property databaseDump
1718 1719 1720 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1718 def database_dump @database_dump end |
#description ⇒ String
Optional. The description of the metadata import.
Corresponds to the JSON property description
1723 1724 1725 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1723 def description @description end |
#end_time ⇒ String
Output only. The time when the metadata import finished.
Corresponds to the JSON property endTime
1728 1729 1730 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1728 def end_time @end_time end |
#name ⇒ String
Immutable. Identifier. The relative resource name of the metadata import, of
the form:projects/project_number/locations/location_id/services/
service_id/metadataImports/metadata_import_id.
Corresponds to the JSON property name
1735 1736 1737 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1735 def name @name end |
#state ⇒ String
Output only. The current state of the metadata import.
Corresponds to the JSON property state
1740 1741 1742 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1740 def state @state end |
#update_time ⇒ String
Output only. The time when the metadata import was last updated.
Corresponds to the JSON property updateTime
1745 1746 1747 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1745 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1752 1753 1754 1755 1756 1757 1758 1759 1760 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1752 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @database_dump = args[:database_dump] if args.key?(:database_dump) @description = args[:description] if args.key?(:description) @end_time = args[:end_time] if args.key?(:end_time) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |