Class: Google::Apis::MetastoreV1beta::MigrationExecution
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1beta::MigrationExecution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb
Overview
The details of a migration execution resource.
Instance Attribute Summary collapse
-
#cloud_sql_migration_config ⇒ Google::Apis::MetastoreV1beta::CloudSqlMigrationConfig
Configuration information for migrating from self-managed hive metastore on Google Cloud using Cloud SQL as the backend database to Dataproc Metastore.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#phase ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#state_message ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MigrationExecution
constructor
A new instance of MigrationExecution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MigrationExecution
Returns a new instance of MigrationExecution.
1862 1863 1864 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1862 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_sql_migration_config ⇒ Google::Apis::MetastoreV1beta::CloudSqlMigrationConfig
Configuration information for migrating from self-managed hive metastore on
Google Cloud using Cloud SQL as the backend database to Dataproc Metastore.
Corresponds to the JSON property cloudSqlMigrationConfig
1827 1828 1829 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1827 def cloud_sql_migration_config @cloud_sql_migration_config end |
#create_time ⇒ String
Output only. The time when the migration execution was started.
Corresponds to the JSON property createTime
1832 1833 1834 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1832 def create_time @create_time end |
#end_time ⇒ String
Output only. The time when the migration execution finished.
Corresponds to the JSON property endTime
1837 1838 1839 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1837 def end_time @end_time end |
#name ⇒ String
Output only. The relative resource name of the migration execution, in the
following form: projects/project_number/locations/location_id/services/
service_id/migrationExecutions/migration_execution_id
Corresponds to the JSON property name
1844 1845 1846 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1844 def name @name end |
#phase ⇒ String
Output only. The current phase of the migration execution.
Corresponds to the JSON property phase
1849 1850 1851 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1849 def phase @phase end |
#state ⇒ String
Output only. The current state of the migration execution.
Corresponds to the JSON property state
1854 1855 1856 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1854 def state @state end |
#state_message ⇒ String
Output only. Additional information about the current state of the migration
execution.
Corresponds to the JSON property stateMessage
1860 1861 1862 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1860 def @state_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1867 1868 1869 1870 1871 1872 1873 1874 1875 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1867 def update!(**args) @cloud_sql_migration_config = args[:cloud_sql_migration_config] if args.key?(:cloud_sql_migration_config) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @name = args[:name] if args.key?(:name) @phase = args[:phase] if args.key?(:phase) @state = args[:state] if args.key?(:state) @state_message = args[:state_message] if args.key?(:state_message) end |