Class: Google::Apis::MetastoreV1beta::MultiRegionMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb

Overview

The metadata for the multi-region that includes the constituent regions. The metadata is only populated if the region is multi-region. For single region or custom dual region, it will be empty.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiRegionMetadata

Returns a new instance of MultiRegionMetadata.



1966
1967
1968
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1966

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#constituent_regionsArray<String>

The regions constituting the multi-region. Corresponds to the JSON property constituentRegions

Returns:

  • (Array<String>)


1954
1955
1956
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1954

def constituent_regions
  @constituent_regions
end

#continentString

The continent for this multi-region. Corresponds to the JSON property continent

Returns:

  • (String)


1959
1960
1961
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1959

def continent
  @continent
end

#witness_regionString

The Spanner witness region for this multi-region. Corresponds to the JSON property witnessRegion

Returns:

  • (String)


1964
1965
1966
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1964

def witness_region
  @witness_region
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1971
1972
1973
1974
1975
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 1971

def update!(**args)
  @constituent_regions = args[:constituent_regions] if args.key?(:constituent_regions)
  @continent = args[:continent] if args.key?(:continent)
  @witness_region = args[:witness_region] if args.key?(:witness_region)
end