Class: Google::Apis::MetastoreV1beta::Restore
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1beta::Restore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb
Overview
The details of a metadata restore operation.
Instance Attribute Summary collapse
-
#backup ⇒ String
Output only.
-
#backup_location ⇒ String
Optional.
-
#details ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Restore
constructor
A new instance of Restore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Restore
Returns a new instance of Restore.
2346 2347 2348 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2346 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup ⇒ String
Output only. The relative resource name of the metastore service backup to
restore from, in the following form:projects/project_id/locations/
location_id/services/service_id/backups/backup_id.
Corresponds to the JSON property backup
2312 2313 2314 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2312 def backup @backup end |
#backup_location ⇒ String
Optional. A Cloud Storage URI specifying where the backup artifacts are stored,
in the format gs:///.
Corresponds to the JSON property backupLocation
2318 2319 2320 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2318 def backup_location @backup_location end |
#details ⇒ String
Output only. The restore details containing the revision of the service to be
restored to, in format of JSON.
Corresponds to the JSON property details
2324 2325 2326 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2324 def details @details end |
#end_time ⇒ String
Output only. The time when the restore ended.
Corresponds to the JSON property endTime
2329 2330 2331 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2329 def end_time @end_time end |
#start_time ⇒ String
Output only. The time when the restore started.
Corresponds to the JSON property startTime
2334 2335 2336 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2334 def start_time @start_time end |
#state ⇒ String
Output only. The current state of the restore.
Corresponds to the JSON property state
2339 2340 2341 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2339 def state @state end |
#type ⇒ String
Output only. The type of restore.
Corresponds to the JSON property type
2344 2345 2346 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2344 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2351 2352 2353 2354 2355 2356 2357 2358 2359 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2351 def update!(**args) @backup = args[:backup] if args.key?(:backup) @backup_location = args[:backup_location] if args.key?(:backup_location) @details = args[:details] if args.key?(:details) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) end |