Class: Google::Apis::MetastoreV1beta::ScheduledBackup
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1beta::ScheduledBackup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb
Overview
This specifies the configuration of scheduled backup.
Instance Attribute Summary collapse
-
#backup_location ⇒ String
Optional.
-
#cron_schedule ⇒ String
Optional.
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
-
#latest_backup ⇒ Google::Apis::MetastoreV1beta::LatestBackup
The details of the latest scheduled backup.
-
#next_scheduled_time ⇒ String
Output only.
-
#time_zone ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ScheduledBackup
constructor
A new instance of ScheduledBackup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ScheduledBackup
Returns a new instance of ScheduledBackup.
2524 2525 2526 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2524 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_location ⇒ String
Optional. A Cloud Storage URI of a folder, in the format gs:///. A sub-folder
containing backup files will be stored below it.
Corresponds to the JSON property backupLocation
2490 2491 2492 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2490 def backup_location @backup_location end |
#cron_schedule ⇒ String
Optional. The scheduled interval in Cron format, see https://en.wikipedia.org/
wiki/Cron The default is empty: scheduled backup is not enabled. Must be
specified to enable scheduled backups.
Corresponds to the JSON property cronSchedule
2497 2498 2499 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2497 def cron_schedule @cron_schedule end |
#enabled ⇒ Boolean Also known as: enabled?
Optional. Defines whether the scheduled backup is enabled. The default value
is false.
Corresponds to the JSON property enabled
2503 2504 2505 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2503 def enabled @enabled end |
#latest_backup ⇒ Google::Apis::MetastoreV1beta::LatestBackup
The details of the latest scheduled backup.
Corresponds to the JSON property latestBackup
2509 2510 2511 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2509 def latest_backup @latest_backup end |
#next_scheduled_time ⇒ String
Output only. The time when the next backups execution is scheduled to start.
Corresponds to the JSON property nextScheduledTime
2514 2515 2516 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2514 def next_scheduled_time @next_scheduled_time end |
#time_zone ⇒ String
Optional. Specifies the time zone to be used when interpreting cron_schedule.
Must be a time zone name from the time zone database (https://en.wikipedia.org/
wiki/List_of_tz_database_time_zones), e.g. America/Los_Angeles or Africa/
Abidjan. If left unspecified, the default is UTC.
Corresponds to the JSON property timeZone
2522 2523 2524 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2522 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2529 2530 2531 2532 2533 2534 2535 2536 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2529 def update!(**args) @backup_location = args[:backup_location] if args.key?(:backup_location) @cron_schedule = args[:cron_schedule] if args.key?(:cron_schedule) @enabled = args[:enabled] if args.key?(:enabled) @latest_backup = args[:latest_backup] if args.key?(:latest_backup) @next_scheduled_time = args[:next_scheduled_time] if args.key?(:next_scheduled_time) @time_zone = args[:time_zone] if args.key?(:time_zone) end |