Class: Google::Apis::MetastoreV1beta::Service

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb

Overview

A managed metastore service that serves metadata queries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Service

Returns a new instance of Service.



2709
2710
2711
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2709

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_gcs_uriString

Output only. A Cloud Storage URI (starting with gs://) that specifies where artifacts related to the metastore service are stored. Corresponds to the JSON property artifactGcsUri

Returns:

  • (String)


2568
2569
2570
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2568

def artifact_gcs_uri
  @artifact_gcs_uri
end

#create_timeString

Output only. The time when the metastore service was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2573
2574
2575
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2573

def create_time
  @create_time
end

#database_typeString

Immutable. The database type that the Metastore service stores its data. Corresponds to the JSON property databaseType

Returns:

  • (String)


2578
2579
2580
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2578

def database_type
  @database_type
end

#deletion_protectionBoolean Also known as: deletion_protection?

Optional. Indicates if the dataproc metastore should be protected against accidental deletions. Corresponds to the JSON property deletionProtection

Returns:

  • (Boolean)


2584
2585
2586
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2584

def deletion_protection
  @deletion_protection
end

#encryption_configGoogle::Apis::MetastoreV1beta::EncryptionConfig

Encryption settings for the service. Corresponds to the JSON property encryptionConfig



2590
2591
2592
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2590

def encryption_config
  @encryption_config
end

#endpoint_uriString

Output only. The URI of the endpoint used to access the metastore service. Corresponds to the JSON property endpointUri

Returns:

  • (String)


2595
2596
2597
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2595

def endpoint_uri
  @endpoint_uri
end

#hive_metastore_configGoogle::Apis::MetastoreV1beta::HiveMetastoreConfig

Specifies configuration information specific to running Hive metastore software as the metastore service. Corresponds to the JSON property hiveMetastoreConfig



2601
2602
2603
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2601

def hive_metastore_config
  @hive_metastore_config
end

#labelsHash<String,String>

User-defined labels for the metastore service. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2606
2607
2608
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2606

def labels
  @labels
end

#maintenance_windowGoogle::Apis::MetastoreV1beta::MaintenanceWindow

Maintenance window. This specifies when Dataproc Metastore may perform system maintenance operation to the service. Corresponds to the JSON property maintenanceWindow



2612
2613
2614
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2612

def maintenance_window
  @maintenance_window
end

#metadata_integrationGoogle::Apis::MetastoreV1beta::MetadataIntegration

Specifies how metastore metadata should be integrated with external services. Corresponds to the JSON property metadataIntegration



2617
2618
2619
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2617

def 
  @metadata_integration
end

#metadata_management_activityGoogle::Apis::MetastoreV1beta::MetadataManagementActivity

The metadata management activities of the metastore service. Corresponds to the JSON property metadataManagementActivity



2622
2623
2624
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2622

def 
  @metadata_management_activity
end

#multi_region_configGoogle::Apis::MetastoreV1beta::MultiRegionConfig

Deprecated: Use a single region service instead. The multi-region config for the Dataproc Metastore service. Corresponds to the JSON property multiRegionConfig



2628
2629
2630
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2628

def multi_region_config
  @multi_region_config
end

#nameString

Immutable. Identifier. The relative resource name of the metastore service, in the following format:projects/project_number/locations/location_id/ services/service_id. Corresponds to the JSON property name

Returns:

  • (String)


2635
2636
2637
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2635

def name
  @name
end

#networkString

Immutable. The relative resource name of the VPC network on which the instance can be accessed. It is specified in the following form:projects/ project_number/global/networks/network_id. Corresponds to the JSON property network

Returns:

  • (String)


2642
2643
2644
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2642

def network
  @network
end

#network_configGoogle::Apis::MetastoreV1beta::NetworkConfig

Network configuration for the Dataproc Metastore service. Corresponds to the JSON property networkConfig



2647
2648
2649
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2647

def network_config
  @network_config
end

#portFixnum

Optional. The TCP port at which the metastore service is reached. Default: 9083. Corresponds to the JSON property port

Returns:

  • (Fixnum)


2653
2654
2655
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2653

def port
  @port
end

#release_channelString

Immutable. The release channel of the service. If unspecified, defaults to STABLE. Corresponds to the JSON property releaseChannel

Returns:

  • (String)


2659
2660
2661
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2659

def release_channel
  @release_channel
end

#scaling_configGoogle::Apis::MetastoreV1beta::ScalingConfig

Represents the scaling configuration of a metastore service. Corresponds to the JSON property scalingConfig



2664
2665
2666
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2664

def scaling_config
  @scaling_config
end

#scheduled_backupGoogle::Apis::MetastoreV1beta::ScheduledBackup

This specifies the configuration of scheduled backup. Corresponds to the JSON property scheduledBackup



2669
2670
2671
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2669

def scheduled_backup
  @scheduled_backup
end

#stateString

Output only. The current state of the metastore service. Corresponds to the JSON property state

Returns:

  • (String)


2674
2675
2676
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2674

def state
  @state
end

#state_messageString

Output only. Additional information about the current state of the metastore service, if available. Corresponds to the JSON property stateMessage

Returns:

  • (String)


2680
2681
2682
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2680

def state_message
  @state_message
end

#tagsHash<String,String>

Optional. Input only. Immutable. Tag keys/values directly bound to this resource. For example: "123/environment": "production", "123/costCenter": " marketing" Corresponds to the JSON property tags

Returns:

  • (Hash<String,String>)


2687
2688
2689
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2687

def tags
  @tags
end

#telemetry_configGoogle::Apis::MetastoreV1beta::TelemetryConfig

Telemetry Configuration for the Dataproc Metastore service. Corresponds to the JSON property telemetryConfig



2692
2693
2694
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2692

def telemetry_config
  @telemetry_config
end

#tierString

Optional. The tier of the service. Corresponds to the JSON property tier

Returns:

  • (String)


2697
2698
2699
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2697

def tier
  @tier
end

#uidString

Output only. The globally unique resource identifier of the metastore service. Corresponds to the JSON property uid

Returns:

  • (String)


2702
2703
2704
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2702

def uid
  @uid
end

#update_timeString

Output only. The time when the metastore service was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2707
2708
2709
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2707

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2714

def update!(**args)
  @artifact_gcs_uri = args[:artifact_gcs_uri] if args.key?(:artifact_gcs_uri)
  @create_time = args[:create_time] if args.key?(:create_time)
  @database_type = args[:database_type] if args.key?(:database_type)
  @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection)
  @encryption_config = args[:encryption_config] if args.key?(:encryption_config)
  @endpoint_uri = args[:endpoint_uri] if args.key?(:endpoint_uri)
  @hive_metastore_config = args[:hive_metastore_config] if args.key?(:hive_metastore_config)
  @labels = args[:labels] if args.key?(:labels)
  @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window)
  @metadata_integration = args[:metadata_integration] if args.key?(:metadata_integration)
  @metadata_management_activity = args[:metadata_management_activity] if args.key?(:metadata_management_activity)
  @multi_region_config = args[:multi_region_config] if args.key?(:multi_region_config)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @network_config = args[:network_config] if args.key?(:network_config)
  @port = args[:port] if args.key?(:port)
  @release_channel = args[:release_channel] if args.key?(:release_channel)
  @scaling_config = args[:scaling_config] if args.key?(:scaling_config)
  @scheduled_backup = args[:scheduled_backup] if args.key?(:scheduled_backup)
  @state = args[:state] if args.key?(:state)
  @state_message = args[:state_message] if args.key?(:state_message)
  @tags = args[:tags] if args.key?(:tags)
  @telemetry_config = args[:telemetry_config] if args.key?(:telemetry_config)
  @tier = args[:tier] if args.key?(:tier)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end