Class: Google::Apis::MetastoreV1beta::StatusProto
- Inherits:
-
Object
- Object
- Google::Apis::MetastoreV1beta::StatusProto
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/metastore_v1beta/classes.rb,
lib/google/apis/metastore_v1beta/representations.rb,
lib/google/apis/metastore_v1beta/representations.rb
Overview
Wire-format for a Status object
Instance Attribute Summary collapse
-
#canonical_code ⇒ Fixnum
copybara:strip_begin(b/383363683) copybara:strip_end_and_replace optional int32 canonical_code = 6; Corresponds to the JSON property
canonicalCode. -
#code ⇒ Fixnum
Numeric code drawn from the space specified below.
-
#message ⇒ String
Detail message copybara:strip_begin(b/383363683) copybara: strip_end_and_replace optional string message = 3; Corresponds to the JSON property
message. -
#message_set ⇒ Google::Apis::MetastoreV1beta::MessageSet
This is proto2's version of MessageSet.DEPRECATED: DO NOT USE FOR NEW FIELDS.
-
#space ⇒ String
copybara:strip_begin(b/383363683) Space to which this status belongs copybara: strip_end_and_replace optional string space = 2; // Space to which this status belongs Corresponds to the JSON property
space.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StatusProto
constructor
A new instance of StatusProto.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StatusProto
Returns a new instance of StatusProto.
2912 2913 2914 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2912 def initialize(**args) update!(**args) end |
Instance Attribute Details
#canonical_code ⇒ Fixnum
copybara:strip_begin(b/383363683) copybara:strip_end_and_replace optional
int32 canonical_code = 6;
Corresponds to the JSON property canonicalCode
2876 2877 2878 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2876 def canonical_code @canonical_code end |
#code ⇒ Fixnum
Numeric code drawn from the space specified below. Often, this is the
canonical error space, and code is drawn from google3/util/task/codes.proto
copybara:strip_begin(b/383363683) copybara:strip_end_and_replace optional
int32 code = 1;
Corresponds to the JSON property code
2884 2885 2886 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2884 def code @code end |
#message ⇒ String
Detail message copybara:strip_begin(b/383363683) copybara:
strip_end_and_replace optional string message = 3;
Corresponds to the JSON property message
2890 2891 2892 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2890 def @message end |
#message_set ⇒ Google::Apis::MetastoreV1beta::MessageSet
This is proto2's version of MessageSet.DEPRECATED: DO NOT USE FOR NEW FIELDS.
If you are using editions or proto2, please make your own extendable messages
for your use case. If you are using proto3, please use Any instead.MessageSet
was the implementation of extensions for proto1. When proto2 was introduced,
extensions were implemented as a first-class feature. This schema for
MessageSet was meant to be a "bridge" solution to migrate MessageSet-bearing
messages from proto1 to proto2.This schema has been open-sourced only to
facilitate the migration of Google products with MessageSet-bearing messages
to open-source environments.
Corresponds to the JSON property messageSet
2903 2904 2905 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2903 def @message_set end |
#space ⇒ String
copybara:strip_begin(b/383363683) Space to which this status belongs copybara:
strip_end_and_replace optional string space = 2; // Space to which this status
belongs
Corresponds to the JSON property space
2910 2911 2912 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2910 def space @space end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2917 2918 2919 2920 2921 2922 2923 |
# File 'lib/google/apis/metastore_v1beta/classes.rb', line 2917 def update!(**args) @canonical_code = args[:canonical_code] if args.key?(:canonical_code) @code = args[:code] if args.key?(:code) @message = args[:message] if args.key?(:message) @message_set = args[:message_set] if args.key?(:message_set) @space = args[:space] if args.key?(:space) end |